@@ -16,11 +16,16 @@ from tornado import web
 from tornado.websocket import WebSocketHandler
 from ypy_websocket.websocket_server import YRoom
 from ypy_websocket.ystore import BaseYStore
-from ypy_websocket.yutils import YMessageType
+from ypy_websocket.yutils import YMessageType, write_var_uint
 
 from .loaders import FileLoaderMapping
 from .rooms import DocumentRoom, TransientRoom
-from .utils import JUPYTER_COLLABORATION_EVENTS_URI, LogLevel, decode_file_path
+from .utils import (
+    JUPYTER_COLLABORATION_EVENTS_URI,
+    LogLevel,
+    MessageType,
+    decode_file_path,
+)
 from .websocketserver import JupyterWebsocketServer
 
 YFILE = YDOCS["file"]
@@ -49,6 +54,7 @@ class YDocWebSocketHandler(WebSocketHandler, JupyterHandler):
     """
 
     _message_queue: asyncio.Queue[Any]
+    _background_tasks: set[asyncio.Task]
 
     def create_task(self, aw):
         task = asyncio.create_task(aw)
@@ -210,6 +216,8 @@ class YDocWebSocketHandler(WebSocketHandler, JupyterHandler):
         On message receive.
         """
         message_type = message[0]
+        print("message type:", message_type)
+
         if message_type == YMessageType.AWARENESS:
             # awareness
             skip = False
@@ -235,6 +243,18 @@ class YDocWebSocketHandler(WebSocketHandler, JupyterHandler):
                 )
                 return skip
 
+        if message_type == MessageType.CHAT:
+            msg = message[2:].decode("utf-8")
+            user = self.get_current_user()
+            data = json.dumps({"username": user.username, "msg": msg}).encode("utf8")
+            for client in self.room.clients:
+                if client != self:
+                    task = asyncio.create_task(
+                        client.send(bytes([MessageType.CHAT]) + write_var_uint(len(data)) + data)
+                    )
+                    self._websocket_server.background_tasks.add(task)
+                    task.add_done_callback(self._websocket_server.background_tasks.discard)
+
         self._message_queue.put_nowait(message)
         self._websocket_server.ypatch_nb += 1
 
